@@ -1,13 +1,14 @@
 #-*- encoding: utf-8 -*-
-VERSION='0.3.6'
-MAX_RETRIES=3
-import sys, time
+VERSION='0.3.8-a'
+MAX_RETRIES=5
+import sys
 try:
     from urllib.request import urlopen, Request
     from urllib.parse import quote_plus
+    from urllib.error import URLError
 except ImportError:
     from urllib import quote_plus
-    from urllib2 import Request, urlopen
+    from urllib2 import Request, urlopen, URLError
 
 try:
     import json
@@ -29,10 +30,10 @@ class JSONScraper(object):
     '''
     def downloadWebData(self, url, headers=None):
         data = ""
-        req = Request(url)
-        req.add_header(Keys.USER_AGENT, Keys.USER_AGENT_STRING)
         for _ in range(MAX_RETRIES):
             try:
+                req = Request(url)
+                req.add_header(Keys.USER_AGENT, Keys.USER_AGENT_STRING)
                 response = urlopen(req)
                 if sys.version_info < (3, 0):
                     data = response.read()
@@ -41,7 +42,10 @@ class JSONScraper(object):
                 response.close()
                 break
             except Exception as err:
-                pass
+                if not isinstance(err, URLError):
+                    self.logger.debug("Error %s during HTTP Request, abort", repr(err))
+                    raise # propagate non-URLError
+                self.logger.debug("Error %s during HTTP Request, retrying", repr(err))
         else:
             raise TwitchException(TwitchException.HTTP_ERROR)
         return data
@@ -162,10 +166,12 @@ class TwitchTV(object):
         return self._fetchItems(url, 'title')
 
     def __getChunkedVideo(self, id):
+        # twitch site queries chunked playlists also with token
+        # not necessary yet but might change (similar to vod playlists)
         url = Urls.VIDEO_PLAYLIST.format(id)
         return self.scraper.getJson(url)
 
-    def __getVideoPlaylistChunked(self, id, maxQuality):
+    def __getVideoPlaylistChunkedArchived(self, id, maxQuality):
         vidChunks = self.__getChunkedVideo(id)
         chunks = []
         if vidChunks['chunks'].get(Keys.QUALITY_LIST_VIDEO[maxQuality]):
@@ -205,8 +211,8 @@ class TwitchTV(object):
 
     def getVideoPlaylist(self, id, maxQuality):
         playlist = [(),()]
-        if(id.startswith('c')):
-            playlist = self.__getVideoPlaylistChunked(id,maxQuality)
+        if(id.startswith(('a','c'))):
+            playlist = self.__getVideoPlaylistChunkedArchived(id,maxQuality)
         elif(id.startswith('v')):
             playlist = self.__getVideoPlaylistVod(id,maxQuality)
         return playlist
